@@ -1,3 +1,4 @@
+import time
 import unittest
 
 from tauk.exceptions import TaukException
@@ -5,7 +6,7 @@ from tests.utils import mock_success
 
 
 class UnitTestListenerTestTwo(unittest.TestCase):
-    @mock_success()
+    @mock_success(multiprocess=True)
     def test_two(self):
         print('running test two')
         self.assertEqual(True, True, 'failed to assert')  # add assertion here
